@@ -11,7 +11,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
@@ -24,37 +24,41 @@ using LongoMatch.Handlers;
 
 namespace LongoMatch.Gui.Dialog
 {
-	
+
 	[System.ComponentModel.Category("LongoMatch")]
 	[System.ComponentModel.ToolboxItem(false)]
 	public partial class SnapshotsDialog : Gtk.Dialog
 	{
-		
-		
-		
-		
-		
+
+
+
+
+
 		public SnapshotsDialog()
 		{
 			this.Build();
 		}
-		
-		public string Play{
-			set{ 				
+
+		public string Play {
+			set {
 				playLabel.Text = value;
 				entry1.Text = value;
 			}
 		}
 
-		public uint Interval{
-			get{return 1000/(uint)spinbutton1.Value;}
+		public uint Interval {
+			get {
+				return 1000/(uint)spinbutton1.Value;
+			}
 		}
-		
-		public string SeriesName{
-			get{return entry1.Text;}
+
+		public string SeriesName {
+			get {
+				return entry1.Text;
+			}
 		}
-		
-		
+
+
 	}
-	
+
 }
